% calculation_eq150.m
%
% Calculations for equations (147), (148), and (150) in proof of 
% Proposition 6.
%
% --
% Supplementary material to
%
% [1] S. Trimpe, R. D'Andrea, "Addendum to: Event-based state estimation 
% with variance-based triggering, IDSC, ETH Zurich, Tech. Rep., 2012.
%
% Copyright:
% Sebastian Trimpe
% ETH Zurich
% Institute for Dynamic Systems and Control (IDSC)
% strimpe(at)ethz.ch
% March 2012
%

% Revision history
% [March 12, Seb]   first version

clear all;
clc;


%% Symbolic variables and expressions
% Variables as defined in [1].  
syms a c p d S;         % d for \delta

% Function g (eq. (24))
g = a^2*p + 1 - a^2*c^2*p^2/(c^2*p+1);

% Solution to DARE: \bar{p}  (eq. (145))
pbar = (a^2-1+c^2+S)/(2*c^2);


%% Preliminary calculations
% derivative g'(p) (eq. (51))
dg = simplify(diff(g,p));

% disp('dg/dp:');
% pretty(dg);
% disp(' ');


%% Calculation
% NUM, DEN as defined in (147) and (148):
NUM = 4*c^2*a^4*(pbar+d);
DEN = 4*c^2*((a^2+c^2)*(pbar+d)+1)*(c^2*(pbar+d)+1);

% % Sanity check:
% expr = a^2*(pbar+d)*subs(dg,p,pbar+d)/subs(g,p,pbar+d); % Eq. (143)
% disp('Sanity check: Result has to be 0.');
% simplify(expr-NUM/DEN)

% Eq. (150): DEN - NUM.
diffDEN_NUM1 = expand(simplify(DEN-NUM));

% Siplification: repace S^2 with (a^2-1+c^2)^2 + 4*c^2.
diffDEN_NUM2 = expand(simplify(subs(diffDEN_NUM1,S^2,(a^2-1+c^2)^2 + 4*c^2)));


%% Display the results
disp('RESULTS (d stands for \delta).');
disp('Equation (147):');
pretty(expand(NUM));
disp(' ');
disp('Equation (148):');
pretty(expand(DEN));
disp(' ');
disp('Equation (150):');
pretty(diffDEN_NUM2);
disp(' ');
